==> haskell-network-ip-0.3.0.3-464-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-ip
version:              0.3.0.3
visibility:           public
id:                   network-ip-0.3.0.3-9g5q6O8QFpDDXeIWc2iyYt
key:                  network-ip-0.3.0.3-9g5q6O8QFpDDXeIWc2iyYt
license:              BSD-3-Clause
copyright:            2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/network-ip
synopsis:             Internet Protocol data structures
description:          This package provides Internet Protocol data structures
category:             Network
abi:                  ea9c95889e533322664713fbdd0ce6d6
exposed:              True
exposed-modules:      Network.IP.Addr
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-ip
hs-libraries:         HSnetwork-ip-0.3.0.3-9g5q6O8QFpDDXeIWc2iyYt
depends:
    base-4.17.2.1 data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi
    data-dword-0.3.2.1-G0TIx7Ys2EYEpECMZsb9cd
    data-endian-0.1.1-7icaZ25RZK5C1z9LOhGoDG
    data-serializer-0.3.5-FJwkVj8zPQD7IZPB9atVbq
    data-textual-0.3.0.3-I7pyBMUaISRCKS8L4qvHep
    hashable-1.4.7.0-5RC0vb199EtDGUMphsJuko
    parsers-0.12.12-ZAuPTjvTfk5DldhmoxnGL
    text-printer-0.5.0.2-5vNAsvNgFXrGB4onEwTbl9
    type-hint-0.1-BLZkEIaqz7B91MRxOq10xP

haddock-interfaces:   /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html:         /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-ip-0.3.0.3-465-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-ip
version:              0.3.0.3
visibility:           public
id:                   network-ip-0.3.0.3-LZRvDRgSO8a4CHQQN6DOgA
key:                  network-ip-0.3.0.3-LZRvDRgSO8a4CHQQN6DOgA
license:              BSD-3-Clause
copyright:            2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/network-ip
synopsis:             Internet Protocol data structures
description:          This package provides Internet Protocol data structures
category:             Network
abi:                  37825d05c09d9d94ffded2f098916ca6
exposed:              True
exposed-modules:      Network.IP.Addr
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-ip-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-ip
hs-libraries:         HSnetwork-ip-0.3.0.3-LZRvDRgSO8a4CHQQN6DOgA
depends:
    base-4.17.2.1 data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi
    data-dword-0.3.2.1-8S0riouYXgKENrOfMutKC6
    data-endian-0.1.1-7icaZ25RZK5C1z9LOhGoDG
    data-serializer-0.3.5-CRVWyp4k2q2qXFc9ue8s9
    data-textual-0.3.0.3-Bky9FHAAVgRB1lTqVdTxHc
    hashable-1.4.7.0-DYciMpMadITBAfaAGwGb6s
    parsers-0.12.12-BQ78sXWsuliJ54KBgsTnTz
    text-printer-0.5.0.2-H7t8XeayN8uLjNqGQwcR8V
    type-hint-0.1-BLZkEIaqz7B91MRxOq10xP

haddock-interfaces:   /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html:         /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
